@@ -1,9 +1,8 @@
+import collections
 import ipaddress
 import numbers
 import re
 
-from collections import Iterable, Mapping
-
 from .chars import SUB_DELIMS
 from .encoding import uriencode
 from .split import uriunsplit
@@ -115,7 +114,7 @@ def _querydict(mapping, sep, encoding):
     for key, value in mapping.items():
         if isinstance(value, _strtypes):
             items.append((key, value))
-        elif isinstance(value, Iterable):
+        elif isinstance(value, collections.Iterable):
             items.extend([(key, v) for v in value])
         else:
             items.append((key, value))
@@ -125,7 +124,7 @@ def _querydict(mapping, sep, encoding):
 def uricompose(scheme=None, authority=None, path='', query=None,
                fragment=None, userinfo=None, host=None, port=None,
                querysep='&', encoding='utf-8'):
-    """Compose a URI string from its individual components."""
+    """Compose a URI reference string from its individual components."""
 
     # RFC 3986 3.1: Scheme names consist of a sequence of characters
     # beginning with a letter and followed by any combination of
@@ -148,7 +147,7 @@ def uricompose(scheme=None, authority=None, path='', query=None,
         authority = _AUTHORITY_RE_BYTES.match(authority).groups()
     elif isinstance(authority, _unicode):
         authority = _AUTHORITY_RE_UNICODE.match(authority).groups()
-    elif not isinstance(authority, Iterable):
+    elif not isinstance(authority, collections.Iterable):
         raise TypeError('Invalid authority type')
     elif len(authority) != 3:
         raise ValueError('Invalid authority length')
@@ -191,9 +190,9 @@ def uricompose(scheme=None, authority=None, path='', query=None,
     # encoding those characters.
     if isinstance(query, _strtypes):
         query = uriencode(query, _SAFE_QUERY, encoding)
-    elif isinstance(query, Mapping):
+    elif isinstance(query, collections.Mapping):
         query = _querydict(query, querysep, encoding)
-    elif isinstance(query, Iterable):
+    elif isinstance(query, collections.Iterable):
         query = _querylist(query, querysep, encoding)
     elif query is not None:
         raise TypeError('Invalid query type')
